/*
 * irreco - Ir Remote Control
 * Copyright (C) 2008 Joni Kokko (t5kojo01@students.oamk.fi)
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "irreco_theme_button.h"

/*
 * Contains information of button
 */
 
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Prototypes                                                                 */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/

/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Construction & Destruction                                                 */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
IrrecoThemeButton *irreco_theme_button_new()
{
	IrrecoThemeButton *self;
	IRRECO_ENTER
	
	self = g_slice_new0(IrrecoThemeButton);
	
	self->name = g_string_new("");
	self->image_up = g_string_new("");
	self->image_down = g_string_new("");
	self->text_format_up = g_string_new("");
	self->text_format_down = g_string_new("");
	self->folder_name = g_string_new("");
	
	IRRECO_RETURN_PTR(self);
}

void irreco_theme_button_free(IrrecoThemeButton *self)
{
	IRRECO_ENTER
			
	g_assert(self != NULL);
	
	g_string_free(self->name, TRUE);
	self->name = NULL;
	
	g_string_free(self->image_up, TRUE);
	self->image_up = NULL;
	
	g_string_free(self->image_down, TRUE);
	self->image_down = NULL;
	
	g_string_free(self->text_format_up, TRUE);
	self->text_format_up = NULL;
	
	g_string_free(self->text_format_down, TRUE);
	self->text_format_down = NULL;
	
	g_string_free(self->folder_name, TRUE);
	self->folder_name = NULL;
	
	g_slice_free(IrrecoThemeButton, self);
	self = NULL;

	IRRECO_RETURN
}

/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Private Functions                                                          */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/

/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Functions                                                                  */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/

void irreco_theme_button_set(IrrecoThemeButton *self,
			     const char *name,
			     gboolean	 allow_text,
			     const char *image_up,
			     const char *image_down,
			     const char *text_format_up,
			     const char *text_format_down,
			     gint	 text_padding,
			     const char *folder_name)
{
	IRRECO_ENTER
	
	g_string_printf(self->name, "%s", name);
	self->allow_text = allow_text;
	g_string_printf(self->image_up, "%s", image_up);
	g_string_printf(self->image_down, "%s", image_down);
	g_string_printf(self->text_format_up, "%s", text_format_up);
	g_string_printf(self->text_format_down, "%s", text_format_down);
	self->text_padding = text_padding;
	g_string_printf(self->folder_name, "%s", folder_name);
	
	IRRECO_RETURN
}

void irreco_theme_button_print(IrrecoThemeButton *self)
{
	IRRECO_ENTER

	IRRECO_PRINTF("Button: %s %d %s %s %s %s %d %s \n",
		      self->name->str, self->allow_text, self->image_up->str,
		      self->image_down->str, self->text_format_up->str,
		      self->text_format_down->str, self->text_padding,
		      self->folder_name->str);

	IRRECO_RETURN
}
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Events and Callbacks                                                       */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/

